Module blaxel.core.client.models.job_metrics
============================================

Classes
-------

`JobMetrics(billable_time: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, cpu_usage: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, executions_chart: blaxel.core.client.types.Unset | ForwardRef('JobMetricsExecutionsChart') = <blaxel.core.client.types.Unset object>, executions_running: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, executions_total: blaxel.core.client.types.Unset | ForwardRef('JobMetricsExecutionsTotal') = <blaxel.core.client.types.Unset object>, ram_usage: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, tasks_chart: blaxel.core.client.types.Unset | ForwardRef('JobMetricsTasksChart') = <blaxel.core.client.types.Unset object>, tasks_running: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, tasks_total: blaxel.core.client.types.Unset | ForwardRef('JobMetricsTasksTotal') = <blaxel.core.client.types.Unset object>)`
:   Metrics for job
    
    Attributes:
        billable_time (Union[Unset, list[Any]]): Billable time
        cpu_usage (Union[Unset, list[Any]]): CPU usage
        executions_chart (Union[Unset, JobMetricsExecutionsChart]): Executions chart
        executions_running (Union[Unset, list[Any]]): Executions running
        executions_total (Union[Unset, JobMetricsExecutionsTotal]): Total executions
        ram_usage (Union[Unset, list[Any]]): RAM usage
        tasks_chart (Union[Unset, JobMetricsTasksChart]): Tasks chart
        tasks_running (Union[Unset, list[Any]]): Tasks running
        tasks_total (Union[Unset, JobMetricsTasksTotal]): Total tasks
    
    Method generated by attrs for class JobMetrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `billable_time`
    :

    `cpu_usage`
    :

    `executions_chart`
    :

    `executions_running`
    :

    `executions_total`
    :

    `ram_usage`
    :

    `tasks_chart`
    :

    `tasks_running`
    :

    `tasks_total`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :